# WRStation - Project file
# Warthog Robotics
# University of Sao Paulo
# https://www.wr.sc.usp.br
# Copyright 2011-2020 Warthog Robotics
# This file is part of WRStation project


# WRStation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# WRStation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# Application info
TEMPLATE = app
DESTDIR  = bin
TARGET   = WRStation
VERSION  = 1.1.2
CONFIG  += c++11

# Qt config
CONFIG += console
CONFIG -= app_bundle
QT     += core gui widgets serialport

# Compilation flags
count(custom_cxxflags, 0) {
    QMAKE_CXXFLAGS_RELEASE = -O2 -Wfloat-equal -Wshadow -Woverloaded-virtual -Wold-style-cast

    count(arch, 1) {
        QMAKE_CXXFLAGS_RELEASE += -march=$$arch
    }
}

# Libraries definitions
LIBS *= -lomniORB4 -lGEARSystem -lomnithread

# Temporary dirs
OBJECTS_DIR = tmp/obj
MOC_DIR     = tmp/moc
UI_DIR      = tmp/moc
RCC_DIR     = tmp/rc

# Source files
INCLUDEPATH *= . include

HEADERS     += include/WRStation/wrstation.hh \
               include/WRStation/namespace.hh \
               include/WRStation/Station/station.hh \
               include/WRStation/GUI/stationgui.hh \
               include/WRStation/CommandPlayerState/commandplayerstate.hh \
               include/WRStation/CommandSerialInterface/commandinterface.hh \
               include/WRStation/CommandSerialInterface/actuatorworker.hh \
               include/WRStation/CommandSerialInterface/serialworker.hh \
               include/WRStation/CommandSerialInterface/GUI/commandserialinterfacegui.hh \
               include/WRStation/CommandSerialInterface/GUI/commandinterfacegui.hh \
               include/WRStation/CommandSerialInterface/GUI/actuatorworkergui.hh \
               include/WRStation/CommandSerialInterface/GUI/serialworkergui.hh \
               include/WRStation/CommandSerialInterface/Protocol/protocol.hh \
               include/WRStation/CommandSerialInterface/Protocol/interface.hh \
               include/WRStation/CommandSerialInterface/Protocol/wrmagiccommandv0.hh


SOURCES     += src/WRStation/wrstation.cc \
               src/WRStation/Station/station.cc \
               src/WRStation/GUI/stationgui.cc \
               src/WRStation/CommandPlayerState/commandplayerstate.cc \
               src/WRStation/CommandSerialInterface/commandinterface.cc \
               src/WRStation/CommandSerialInterface/actuatorworker.cc \
               src/WRStation/CommandSerialInterface/serialworker.cc \
               src/WRStation/CommandSerialInterface/GUI/commandserialinterfacegui.cc \
               src/WRStation/CommandSerialInterface/GUI/commandinterfacegui.cc \
               src/WRStation/CommandSerialInterface/GUI/actuatorworkergui.cc \
               src/WRStation/CommandSerialInterface/GUI/serialworkergui.cc \
               src/WRStation/CommandSerialInterface/Protocol/wrmagiccommandv0.cc \
               src/main.cc


DISTFILES   += pre-build.sh \
               LICENSE

# Installation path
bin_files.files = bin/WRStation

count(bin_path, 0) {
    bin_files.path = /usr/bin/
}

count(bin_path, 1) {
    bin_files.path = $$bin_path
}


INSTALLS += bin_files
