/**
  * Warthog Robotics
  * University of Sao Paulo (USP) at Sao Carlos
  * http://www.warthog.sc.usp.br/
  * This file is part of the WRStation project
  *
  * Copyright (C) 2017 Warthog Robotics
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  **/

// Prevents multiple definitions
#ifndef WRSTATION_COMMANDPLAYERSTATE
#define WRSTATION_COMMANDPLAYERSTATE


// Includes WRStation
#include <WRStation/wrstation.hh>


// Includes Qt libraries
#include <QtCore/QtCore>


// TODO: Insert class and method descriptions
class WRStation::CommandPlayerState {
    private:
        quint8     _teamNumber;
        quint8     _playerNumber;
        QByteArray _playerAddress;


    private:
        float _xSpeed;
        float _ySpeed;
        float _angularSpeed;
        bool  _kickOnTouchEnable;
        float _kickOnTouchPower;
        bool  _chipKickOnTouchEnable;
        float _chipKickOnTouchPower;
        bool  _holdBallEnable;


    public:
        CommandPlayerState();


    public:
        void clear();
        void clearState();


    public:
        quint8 teamNumber() const;
        quint8 playerNumber() const;
        QByteArray playerAddress() const;

    public:
        void setTeamNumber(quint8 teamNum);
        void setPlayerNumber(quint8 playerNum);
        void setPlayerAddress(const QByteArray& address);


    public:
        float xSpeed() const;
        float ySpeed() const;
        float angularSpeed() const;
        bool  kickOnTouchEnable() const;
        float kickOnTouchPower() const;
        bool  chipKickOnTouchEnable() const;
        float chipKickOnTouchPower() const;
        bool  holdBallEnable() const;

    public:
        void setXSpeed(float speed);
        void setYSpeed(float speed);
        void setAngularSpeed(float speed);
        void enableKickOnTouch(bool enable);
        void setKickOnTouchPower(float power);
        void enableChipKickOnTouch(bool enable);
        void setChipKickOnTouchPower(float power);
        void enableHoldBall(bool enable);

    public:
        void setSpeed(float xSpeed, float ySpeed, float angularSpeed);
        void kickOnTouch(bool enable, float power);
        void chipKickOnTouch(bool enable, float power);
        void holdBall(bool enable);
};


#endif
