/**
  * Warthog Robotics
  * University of Sao Paulo (USP) at Sao Carlos
  * http://www.warthog.sc.usp.br/
  * This file is part of the WRStation project
  *
  * Copyright (C) 2017 Warthog Robotics
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  **/

// Prevents multiple definitions
#ifndef WRSTATION_COMMANDSERIALINTERFACE_GUI_ACTUATORWORKERGUI
#define WRSTATION_COMMANDSERIALINTERFACE_GUI_ACTUATORWORKERGUI


// Includes WRStation
#include <WRStation/wrstation.hh>
#include <WRStation/CommandSerialInterface/actuatorworker.hh>


// Includes Qt libraries
#include <QtCore/QtCore>
#include <QtGui/QtGui>
#include <QtWidgets/QtWidgets>


// Includes GEARSystem library
#include <GEARSystem/gearsystem.hh>


// TODO: Insert class and method descriptions
class WRStation::CommandSerialInterface::GUI::ActuatorWorkerGUI : public QWidget {
    Q_OBJECT

    private:
        WRStation::CommandSerialInterface::ActuatorWorker* _actuatorWorker;


    private:
        bool _isActuatorConnected;

    private:
        QLineEdit*   _serverAddressEdit;
        QSpinBox*    _serverPortEdit;
        QLabel*      _serverIsConnectedLabel;
        QPushButton* _serverConnectButton;


    public:
        ActuatorWorkerGUI(QWidget* parent, WRStation::CommandSerialInterface::ActuatorWorker* actuatorWorker);


    public slots:
        void setActuatorConnecting();
        void setActuatorConnected();
        void setActuatorDisconnected();
        void setActuatorConnectFail(const QString& error);
        void setActuatorIsConnected(bool connected);
        void onServerConnectButtonReleased();


    signals:
        void connectActuator(const QString& address, quint16 port);
        void disconnectActuator();


    private:
        void setupGUI();
        void connectSignals();
};


#endif
