/**
  * Warthog Robotics
  * University of Sao Paulo (USP) at Sao Carlos
  * http://www.warthog.sc.usp.br/
  * This file is part of the WRStation project
  *
  * Copyright (C) 2017 Warthog Robotics
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  **/

// Prevents multiple definitions
#ifndef WRSTATION_COMMANDSERIALINTERFACE_GUI_SERIALWORKERGUI
#define WRSTATION_COMMANDSERIALINTERFACE_GUI_SERIALWORKERGUI


// Includes WRStation
#include <WRStation/wrstation.hh>


// Includes Qt libraries
#include <QtCore/QtCore>
#include <QtGui/QtGui>
#include <QtWidgets/QtWidgets>
#include <QtSerialPort/QtSerialPort>


class WRStation::CommandSerialInterface::GUI::SerialWorkerGUI : public QWidget {
    Q_OBJECT

    private:
        WRStation::CommandSerialInterface::SerialWorker* _serialWorker;

	private:
        bool _isSerialPortOpen;
        bool _isSerialPortRunning;

    private:
        QLineEdit*   _serialPortNameEdit;
        QLabel*      _serialPortIsOpenLabel;
        QLabel*      _serialPortIsRunningLabel;
        QLabel*      _serialPortErrorLabel;
        QSpinBox*    _serialPortBaudEdit;
        QComboBox*   _serialPortDataBitsEdit;
        QComboBox*   _serialPortParityEdit;
        QComboBox*   _serialPortStopBitsEdit;
        QComboBox*   _serialPortFlowControlEdit;

        QPushButton* _serialPortOpenButton;
        QPushButton* _serialPortConfigureButton;
        QPushButton* _serialPortStartButton;

        QComboBox*   _serialPortProtocolEdit;
        QLabel*      _serialPortProtocolNameLabel;
        QLabel*      _serialPortProtocolVersionLabel;
        QPushButton* _serialPortProtocolButton;


    public:
        SerialWorkerGUI(QWidget* parent, WRStation::CommandSerialInterface::SerialWorker* serialWorker);


    public slots:
        void setSerialPortBaudRate(qint32 baudRate);
        void setSerialPortClosed();
        void setSerialPortDataBits(QSerialPort::DataBits dataBits);
        void setSerialPortError(QSerialPort::SerialPortError error);
        void setSerialPortErrorString(const QString& errorString);
        void setSerialPortFlowControl(QSerialPort::FlowControl flow);
        void setSerialPortIsOpen(bool open);
        void setSerialPortName(const QString& name);
        void setSerialPortOpen();
        void setSerialPortParity(QSerialPort::Parity parity);
        void setSerialPortStopBits(QSerialPort::StopBits stopBits);

        void onSerialPortOpenButtonReleased();
        void onSerialPortConfigureButtonReleased();
        void onSerialPortStartButtonReleased();
        void onSerialPortProtocolButtonReleased();

    signals:
        void serialPortClose();
        void serialPortOpen(const QString& portName);
        void serialPortSetBaudRate(qint32 baudRate);
        void serialPortSetDataBits(QSerialPort::DataBits dataBits);
        void serialPortSetFlowControl(QSerialPort::FlowControl flowControl);
        void serialPortSetParity(QSerialPort::Parity parity);
        void serialPortSetStopBits(QSerialPort::StopBits stopBits);

    signals:
        void checkSeriaPortErrorString();


    public slots:
        void setTimerIsRunning(bool isRunning);
        void setTimerStarted();
        void setTimerStopped();

    signals:
        void timerStart();
        void timerStop();


    private:
        void setupGUI();
        void connectSignals();

        static QSerialPort::DataBits str2databits(QString dataBitsStr);
        static QSerialPort::FlowControl str2flowcontrol(QString flowControlStr);
        static QSerialPort::Parity str2parity(QString parityStr);
        static QSerialPort::StopBits str2stopbits(QString stopBitsStr);
};


#endif
