/**
  * Warthog Robotics
  * University of Sao Paulo (USP) at Sao Carlos
  * http://www.warthog.sc.usp.br/
  * This file is part of the WRStation project
  *
  * Copyright (C) 2017 Warthog Robotics
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  **/

// Prevents multiple definitions
#ifndef WRSTATION_COMMANDSERIALINTERFACE_ACTUATORWORKER
#define WRSTATION_COMMANDSERIALINTERFACE_ACTUATORWORKER


// Includes WRStation
#include <WRStation/wrstation.hh>


// Includes Qt libraries
#include <QtCore/QtCore>


// Includes GEARSystem library
#include <GEARSystem/gearsystem.hh>


// TODO: Insert class and method descriptions
class WRStation::CommandSerialInterface::ActuatorWorker : public QObject, public GEARSystem::Actuator {
    Q_OBJECT

    private:
        QHash< quint8, QHash<quint8, bool> >  _controlledPlayers;


    public:
        ActuatorWorker(QObject* parent, const QString& name);


    public slots:
        void reset();

    signals:
        void hasReset();


    public slots:
        void connectActuator(const QString& address, uint16 port);
        void disconnectActuator();
        void checkIsActuatorConnected() const;

    signals:
        void actuatorConnecting();
        void actuatorConnected();
        void actuatorDisconnected();
        void actuatorConnectFail(const QString& error);
        void isActuatorConnected(bool isConnected) const;


    public:
        void setSpeed(quint8 teamNum, quint8 playerNum, float xSpeed, float ySpeed, float angularSpeed);
        void kickOnTouch(quint8 teamNum, quint8 playerNum, bool enable, float power);
        void chipKickOnTouch(quint8 teamNum, quint8 playerNum, bool enable, float power);
        void holdBall(quint8 teamNum, quint8 playerNum, bool enable);
        void kick(quint8 teamNum, quint8 playerNum, float power);
        void chipKick(quint8 teamNum, quint8 playerNum, float power);

    signals:
        void setSpeedReceived(quint8 teamNum, quint8 playerNum, float xSpeed, float ySpeed, float angularSpeed);
        void kickOnTouchReceived(quint8 teamNum, quint8 playerNum, bool enable, float power);
        void chipKickOnTouchReceived(quint8 teamNum, quint8 playerNum, bool enable, float power);
        void holdBallReceived(quint8 teamNum, quint8 playerNum, bool enable);
        void kickReceived(quint8 teamNum, quint8 playerNum, float power);
        void chipKickReceived(quint8 teamNum, quint8 playerNum, float power);


    public slots:
        void addControlledPlayer(quint8 teamNum, quint8 playerNum);
        void delControlledPlayer(quint8 teamNum, quint8 playerNum);
        void setControlledPlayer(quint8 teamNum, quint8 playerNum, bool controlled, bool enabled);
        void enableControlledPlayer(quint8 teamNum, quint8 playerNum, bool enable);

    private:
        bool isPlayerControlled(quint8 teamNum, quint8 playerNum) const;
        bool isPlayerEnabled(quint8 teamNum, quint8 playerNum) const;
};


#endif
