/**
  * Warthog Robotics
  * University of Sao Paulo (USP) at Sao Carlos
  * http://www.warthog.sc.usp.br/
  * This file is part of the WRStation project
  *
  * Copyright (C) 2017 Warthog Robotics
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  **/

// Includes class header
#include <WRStation/CommandPlayerState/commandplayerstate.hh>


// Includes WRStation
#include <WRStation/wrstation.hh>


// Includes Qt libraries
#include <QtCore/QtCore>


// Selects namespace
using namespace WRStation;



WRStation::CommandPlayerState::CommandPlayerState() {
    // Initalizes the states
    this->clear();
}


void WRStation::CommandPlayerState::clear() {
    // Clears player information
    _teamNumber = -1;
    _playerNumber = -1;
    _playerAddress.clear();

    // Clears the state
    this->clearState();
}

void WRStation::CommandPlayerState::clearState() {
    // Clears the state
    _xSpeed = 0.0;
    _ySpeed = 0.0;
    _angularSpeed = 0.0;
    _kickOnTouchEnable = false;
    _kickOnTouchPower = 0.0;
    _chipKickOnTouchEnable = false;
    _chipKickOnTouchPower = 0.0;
    _holdBallEnable = false;
}


quint8 WRStation::CommandPlayerState::teamNumber() const {
    // Returns the team number
    return(_teamNumber);
}

quint8 WRStation::CommandPlayerState::playerNumber() const {
    // Returns the player number
    return(_playerNumber);
}

QByteArray WRStation::CommandPlayerState::playerAddress() const {
    // Returns the player address
    return(_playerAddress);
}


void WRStation::CommandPlayerState::setTeamNumber(quint8 teamNum) {
    // Sets the team number
    _teamNumber = teamNum;
}

void WRStation::CommandPlayerState::setPlayerNumber(quint8 playerNum) {
    // Sets the player number
    _playerNumber = playerNum;
}

void WRStation::CommandPlayerState::setPlayerAddress(const QByteArray& address) {
    // Sets the player address
    _playerAddress = address;
}


float WRStation::CommandPlayerState::xSpeed() const {
    // Returns the speed
    return(_xSpeed);
}

float WRStation::CommandPlayerState::ySpeed() const {
    // Returns the speed
    return(_ySpeed);
}

float WRStation::CommandPlayerState::angularSpeed() const {
    // Returns the speed
    return(_angularSpeed);
}

bool WRStation::CommandPlayerState::kickOnTouchEnable() const {
    // Returns the flag
    return(_kickOnTouchEnable);
}

float WRStation::CommandPlayerState::kickOnTouchPower() const {
    // Returns the power
    return(_kickOnTouchPower);
}

bool WRStation::CommandPlayerState::chipKickOnTouchEnable() const {
    // Returns the flag
    return(_chipKickOnTouchEnable);
}

float WRStation::CommandPlayerState::chipKickOnTouchPower() const {
    // Returns the power
    return(_chipKickOnTouchPower);
}

bool WRStation::CommandPlayerState::holdBallEnable() const {
    // Returns the flag
    return(_holdBallEnable);
}


void WRStation::CommandPlayerState::setXSpeed(float speed) {
    // Sets the speed
    _xSpeed = speed;
}

void WRStation::CommandPlayerState::setYSpeed(float speed) {
    // Sets the speed
    _ySpeed = speed;
}

void WRStation::CommandPlayerState::setAngularSpeed(float speed) {
    // Sets the speed
    _angularSpeed = speed;
}

void WRStation::CommandPlayerState::enableKickOnTouch(bool enable) {
    // Sets the flag
    _kickOnTouchEnable = enable;
}

void WRStation::CommandPlayerState::setKickOnTouchPower(float power) {
    // Sets the power
    _kickOnTouchPower = power;
}

void WRStation::CommandPlayerState::enableChipKickOnTouch(bool enable) {
    // Sets the flag
    _chipKickOnTouchEnable = enable;
}

void WRStation::CommandPlayerState::setChipKickOnTouchPower(float power) {
    // Sets the power
    _chipKickOnTouchPower = power;
}

void WRStation::CommandPlayerState::enableHoldBall(bool enable) {
    // Sets the flag
    _holdBallEnable = enable;
}


void WRStation::CommandPlayerState::setSpeed(float xSpeed, float ySpeed, float angularSpeed) {
    // Sets the speeds
    this->setXSpeed(xSpeed);
    this->setYSpeed(ySpeed);
    this->setAngularSpeed(angularSpeed);
}

void WRStation::CommandPlayerState::kickOnTouch(bool enable, float power) {
    // Sets the enable flag and the power
    this->enableKickOnTouch(enable);
    this->setKickOnTouchPower(enable ? power : 0.0);
}

void WRStation::CommandPlayerState::chipKickOnTouch(bool enable, float power) {
    // Sets the enable flag and the power
    this->enableChipKickOnTouch(enable);
    this->setChipKickOnTouchPower(enable ? power : 0.0);
}

void WRStation::CommandPlayerState::holdBall(bool enable) {
    // Sets the enable flag
    this->enableHoldBall(enable);
}
