/**
  * Warthog Robotics
  * University of Sao Paulo (USP) at Sao Carlos
  * http://www.warthog.sc.usp.br/
  * This file is part of the WRStation project
  *
  * Copyright (C) 2017 Warthog Robotics
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  **/

// Includes class header
#include <WRStation/CommandSerialInterface/GUI/commandserialinterfacegui.hh>


// Includes WRStation
#include <WRStation/wrstation.hh>


// Includes Qt libraries
#include <QtCore/QtCore>
#include <QtGui/QtGui>
#include <QtWidgets/QtWidgets>

#include <iostream>


// Selects namespace
using namespace WRStation;


WRStation::CommandSerialInterface::GUI::CommandSerialInterfaceGUI::CommandSerialInterfaceGUI(QWidget* parent, CommandSerialInterface::CommandInterface* commandInterface) : QWidget(parent), _tabWidget(this) {
    // Sets the controlled command interface
    _commandInterface = commandInterface;

    // Sets the object name
    this->setObjectName(this->metaObject()->className());
    this->resize(10, 10);

    // Set layout
    QVBoxLayout* layout = new QVBoxLayout();
    layout->addWidget(&_tabWidget);
    this->setLayout(layout);

    // Creates the command serial interface GUI
    _commandInterfaceGUI = new CommandSerialInterface::GUI::CommandInterfaceGUI(this, _commandInterface);
    _actuatorWorkerGUI   = new CommandSerialInterface::GUI::ActuatorWorkerGUI(this, _commandInterface->actuatorWorker());
    _serialWorkerGUI     = new CommandSerialInterface::GUI::SerialWorkerGUI(this, _commandInterface->serialWorker());

    // Creates and configures the tab widget
    _tabWidget.setTabPosition(QTabWidget::North);
    _tabWidget.setIconSize(QSize(24,24));

    // Adds actuator worker tab
    _tabWidget.addTab(_actuatorWorkerGUI, QString::fromUtf8("ActuatorWorker"));

    // Adds serial worker tab
    _tabWidget.addTab(_serialWorkerGUI, QString::fromUtf8("SerialWorker"));

    // Adds command interface tab
    _tabWidget.addTab(_commandInterfaceGUI, QString::fromUtf8("CommandInterface (TODO)"));
    _tabWidget.tabBar()->setTabEnabled(_tabWidget.count()-1, false); // remove this to enable CommandInterface tab
}
