/**
  * Warthog Robotics
  * University of Sao Paulo (USP) at Sao Carlos
  * http://www.warthog.sc.usp.br/
  * This file is part of the WRStation project
  *
  * Copyright (C) 2017 Warthog Robotics
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  **/

// Includes class header
#include <WRStation/GUI/stationgui.hh>


// Includes WRStation
#include <WRStation/wrstation.hh>


// Includes Qt libraries
#include <QtCore/QtCore>
#include <QtGui/QtGui>
#include <QtWidgets/QtWidgets>


// Selects namespace
using namespace WRStation;


WRStation::GUI::StationGUI::StationGUI(Station *station, QWidget *parent) : QWidget(parent), _tabWidget(this) {
    // Sets the controlled station
    _station = station;

    // Sets the object name
    this->setObjectName(this->metaObject()->className());

    // Centralizes the screen and sets the window icon
    this->resize(QSize(500,400));
    this->move(QApplication::desktop()->availableGeometry().center() - this->rect().center());
    this->setWindowIcon(QIcon(QString::fromUtf8("/usr/share/warthog-robotics/logos/wr_logo.svg"))); // TODO: make this generic so it can work in any OS

    // Setup GUI
    this->setupGUI();

    // Connect signals
    this->connectSignals();
}

void WRStation::GUI::StationGUI::StationGUI::setupGUI() {
    QVBoxLayout* layout = new QVBoxLayout();
    layout->addWidget(&_tabWidget);
    this->setLayout(layout);

    // Creates the command serial interface GUI
    _commandSerialInterfaceGUI = new CommandSerialInterface::GUI::CommandSerialInterfaceGUI(this, _station->commandSerialInterface());

    // Creates and configures the tab widget
    _tabWidget.setTabPosition(QTabWidget::North);
    _tabWidget.setIconSize(QSize(24,24));

    // Adds command serial interface tab
    _tabWidget.addTab(_commandSerialInterfaceGUI, QString::fromUtf8("CommandSerialInterface"));

    // Create button for hiding GUI
    _btnHide.setText("Hide GUI");
    layout->addWidget(&_btnHide);
}

void WRStation::GUI::StationGUI::StationGUI::connectSignals() {
    QObject::connect(&_btnHide, SIGNAL(released()), this, SLOT(btnHideClicked()));
}

void WRStation::GUI::StationGUI::StationGUI::btnHideClicked() {
    this->hide();
}

